# coding: utf-8

# flake8: noqa
"""
    Kleister OpenAPI

    API definition for Kleister, manage mod packs for Minecraft

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: kleister@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from kleister.models.attach_build_to_version_request import AttachBuildToVersionRequest
from kleister.models.attach_minecraft_to_build_request import AttachMinecraftToBuildRequest
from kleister.models.auth_token import AuthToken
from kleister.models.auth_verify import AuthVerify
from kleister.models.build import Build
from kleister.models.build_version import BuildVersion
from kleister.models.create_build_request import CreateBuildRequest
from kleister.models.create_group_request import CreateGroupRequest
from kleister.models.create_mod_request import CreateModRequest
from kleister.models.create_pack_request import CreatePackRequest
from kleister.models.create_user_request import CreateUserRequest
from kleister.models.create_version_request import CreateVersionRequest
from kleister.models.delete_group_from_mod_request import DeleteGroupFromModRequest
from kleister.models.delete_group_from_pack_request import DeleteGroupFromPackRequest
from kleister.models.delete_pack_from_group_request import DeletePackFromGroupRequest
from kleister.models.delete_pack_from_user_request import DeletePackFromUserRequest
from kleister.models.fabric import Fabric
from kleister.models.forge import Forge
from kleister.models.group import Group
from kleister.models.group_mod import GroupMod
from kleister.models.group_pack import GroupPack
from kleister.models.list_build_versions200_response import ListBuildVersions200Response
from kleister.models.list_builds200_response import ListBuilds200Response
from kleister.models.list_fabric_builds200_response import ListFabricBuilds200Response
from kleister.models.list_fabrics200_response import ListFabrics200Response
from kleister.models.list_forge_builds200_response import ListForgeBuilds200Response
from kleister.models.list_forges200_response import ListForges200Response
from kleister.models.list_group_mods200_response import ListGroupMods200Response
from kleister.models.list_group_packs200_response import ListGroupPacks200Response
from kleister.models.list_group_users200_response import ListGroupUsers200Response
from kleister.models.list_groups200_response import ListGroups200Response
from kleister.models.list_minecraft_builds200_response import ListMinecraftBuilds200Response
from kleister.models.list_minecrafts200_response import ListMinecrafts200Response
from kleister.models.list_mod_groups200_response import ListModGroups200Response
from kleister.models.list_mod_users200_response import ListModUsers200Response
from kleister.models.list_mods200_response import ListMods200Response
from kleister.models.list_neoforge_builds200_response import ListNeoforgeBuilds200Response
from kleister.models.list_neoforges200_response import ListNeoforges200Response
from kleister.models.list_pack_groups200_response import ListPackGroups200Response
from kleister.models.list_pack_users200_response import ListPackUsers200Response
from kleister.models.list_packs200_response import ListPacks200Response
from kleister.models.list_providers200_response import ListProviders200Response
from kleister.models.list_quilt_builds200_response import ListQuiltBuilds200Response
from kleister.models.list_quilts200_response import ListQuilts200Response
from kleister.models.list_user_groups200_response import ListUserGroups200Response
from kleister.models.list_user_mods200_response import ListUserMods200Response
from kleister.models.list_user_packs200_response import ListUserPacks200Response
from kleister.models.list_users200_response import ListUsers200Response
from kleister.models.list_version_builds200_response import ListVersionBuilds200Response
from kleister.models.list_versions200_response import ListVersions200Response
from kleister.models.login_auth_request import LoginAuthRequest
from kleister.models.minecraft import Minecraft
from kleister.models.mod import Mod
from kleister.models.mod_avatar import ModAvatar
from kleister.models.neoforge import Neoforge
from kleister.models.notification import Notification
from kleister.models.pack import Pack
from kleister.models.pack_avatar import PackAvatar
from kleister.models.permit_group_mod_request import PermitGroupModRequest
from kleister.models.permit_group_pack_request import PermitGroupPackRequest
from kleister.models.permit_pack_group_request import PermitPackGroupRequest
from kleister.models.permit_pack_user_request import PermitPackUserRequest
from kleister.models.profile import Profile
from kleister.models.provider import Provider
from kleister.models.quilt import Quilt
from kleister.models.redirect_auth_request import RedirectAuthRequest
from kleister.models.update_profile_request import UpdateProfileRequest
from kleister.models.update_user_request import UpdateUserRequest
from kleister.models.user import User
from kleister.models.user_auth import UserAuth
from kleister.models.user_group import UserGroup
from kleister.models.user_mod import UserMod
from kleister.models.user_pack import UserPack
from kleister.models.validation import Validation
from kleister.models.version import Version
from kleister.models.version_file import VersionFile



# coding: utf-8

"""
    Kleister OpenAPI

    API definition for Kleister, manage mod packs for Minecraft

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: kleister@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from kleister.models.build import Build
from kleister.models.neoforge import Neoforge
from typing import Optional, Set
from typing_extensions import Self

class ListNeoforgeBuilds200Response(BaseModel):
    """
    ListNeoforgeBuilds200Response
    """ # noqa: E501
    total: StrictInt
    limit: StrictInt
    offset: StrictInt
    neoforge: Optional[Neoforge] = None
    builds: List[Build]
    __properties: ClassVar[List[str]] = ["total", "limit", "offset", "neoforge", "builds"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ListNeoforgeBuilds200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of neoforge
        if self.neoforge:
            _dict['neoforge'] = self.neoforge.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in builds (list)
        _items = []
        if self.builds:
            for _item_builds in self.builds:
                if _item_builds:
                    _items.append(_item_builds.to_dict())
            _dict['builds'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ListNeoforgeBuilds200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "total": obj.get("total"),
            "limit": obj.get("limit"),
            "offset": obj.get("offset"),
            "neoforge": Neoforge.from_dict(obj["neoforge"]) if obj.get("neoforge") is not None else None,
            "builds": [Build.from_dict(_item) for _item in obj["builds"]] if obj.get("builds") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kleister OpenAPI

    API definition for Kleister, manage mod packs for Minecraft

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: kleister@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, SecretStr, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from kleister.models.user_auth import UserAuth
from kleister.models.user_group import UserGroup
from kleister.models.user_mod import UserMod
from kleister.models.user_pack import UserPack
from typing import Optional, Set
from typing_extensions import Self

class Profile(BaseModel):
    """
    Model to represent profile
    """ # noqa: E501
    id: Optional[StrictStr] = None
    username: Optional[StrictStr] = None
    password: Optional[SecretStr] = None
    email: Optional[StrictStr] = None
    fullname: Optional[StrictStr] = None
    profile: Optional[StrictStr] = None
    admin: Optional[StrictBool] = None
    active: Optional[StrictBool] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    auths: Optional[List[UserAuth]] = None
    groups: Optional[List[UserGroup]] = None
    mods: Optional[List[UserMod]] = None
    packs: Optional[List[UserPack]] = None
    __properties: ClassVar[List[str]] = ["id", "username", "password", "email", "fullname", "profile", "admin", "active", "created_at", "updated_at", "auths", "groups", "mods", "packs"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Profile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "admin",
            "active",
            "created_at",
            "updated_at",
            "auths",
            "groups",
            "mods",
            "packs",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in auths (list)
        _items = []
        if self.auths:
            for _item_auths in self.auths:
                if _item_auths:
                    _items.append(_item_auths.to_dict())
            _dict['auths'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in groups (list)
        _items = []
        if self.groups:
            for _item_groups in self.groups:
                if _item_groups:
                    _items.append(_item_groups.to_dict())
            _dict['groups'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in mods (list)
        _items = []
        if self.mods:
            for _item_mods in self.mods:
                if _item_mods:
                    _items.append(_item_mods.to_dict())
            _dict['mods'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in packs (list)
        _items = []
        if self.packs:
            for _item_packs in self.packs:
                if _item_packs:
                    _items.append(_item_packs.to_dict())
            _dict['packs'] = _items
        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if profile (nullable) is None
        # and model_fields_set contains the field
        if self.profile is None and "profile" in self.model_fields_set:
            _dict['profile'] = None

        # set to None if auths (nullable) is None
        # and model_fields_set contains the field
        if self.auths is None and "auths" in self.model_fields_set:
            _dict['auths'] = None

        # set to None if groups (nullable) is None
        # and model_fields_set contains the field
        if self.groups is None and "groups" in self.model_fields_set:
            _dict['groups'] = None

        # set to None if mods (nullable) is None
        # and model_fields_set contains the field
        if self.mods is None and "mods" in self.model_fields_set:
            _dict['mods'] = None

        # set to None if packs (nullable) is None
        # and model_fields_set contains the field
        if self.packs is None and "packs" in self.model_fields_set:
            _dict['packs'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Profile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "username": obj.get("username"),
            "password": obj.get("password"),
            "email": obj.get("email"),
            "fullname": obj.get("fullname"),
            "profile": obj.get("profile"),
            "admin": obj.get("admin"),
            "active": obj.get("active"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "auths": [UserAuth.from_dict(_item) for _item in obj["auths"]] if obj.get("auths") is not None else None,
            "groups": [UserGroup.from_dict(_item) for _item in obj["groups"]] if obj.get("groups") is not None else None,
            "mods": [UserMod.from_dict(_item) for _item in obj["mods"]] if obj.get("mods") is not None else None,
            "packs": [UserPack.from_dict(_item) for _item in obj["packs"]] if obj.get("packs") is not None else None
        })
        return _obj


